"""
Warden Java AST provider.

Provides Java code parsing using JavaParser library via JPype1.
"""

from warden_ast_java.provider import JavaParserProvider

__all__ = ["JavaParserProvider"]
__version__ = "0.1.0"
