"""
Fortification module.

This module provides code fortification capabilities (placeholder for future implementation).
Currently provides data models for Panel integration.
"""

from warden.fortification.domain.models import Fortification, FortificationResult

__all__ = [
    "Fortification",
    "FortificationResult",
]
