# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: warden.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'warden.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0cwarden.proto\x12\x06warden\"\x07\n\x05\x45mpty\"\xe2\x02\n\x07\x46inding\x12\n\n\x02id\x18\x01 \x01(\t\x12\r\n\x05title\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\"\n\x08severity\x18\x04 \x01(\x0e\x32\x10.warden.Severity\x12\x11\n\tfile_path\x18\x05 \x01(\t\x12\x13\n\x0bline_number\x18\x06 \x01(\x05\x12\x15\n\rcolumn_number\x18\x07 \x01(\x05\x12\x14\n\x0c\x63ode_snippet\x18\x08 \x01(\t\x12\x12\n\nsuggestion\x18\t \x01(\t\x12\x10\n\x08\x66rame_id\x18\n \x01(\t\x12\x0e\n\x06\x63we_id\x18\x0b \x01(\t\x12\x16\n\x0eowasp_category\x18\x0c \x01(\t\x12/\n\x08metadata\x18\r \x03(\x0b\x32\x1d.warden.Finding.MetadataEntry\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xcd\x01\n\rFortification\x12\n\n\x02id\x18\x01 \x01(\t\x12\r\n\x05title\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x11\n\tfile_path\x18\x04 \x01(\t\x12\x13\n\x0bline_number\x18\x05 \x01(\x05\x12\x15\n\roriginal_code\x18\x06 \x01(\t\x12\x16\n\x0esuggested_code\x18\x07 \x01(\t\x12\x11\n\trationale\x18\x08 \x01(\t\x12\"\n\x08priority\x18\t \x01(\x0e\x32\x10.warden.Severity\"r\n\x08\x43leaning\x12\n\n\x02id\x18\x01 \x01(\t\x12\r\n\x05title\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x11\n\tfile_path\x18\x04 \x01(\t\x12\x13\n\x0bline_number\x18\x05 \x01(\x05\x12\x0e\n\x06\x64\x65tail\x18\x06 \x01(\t\"\xf5\x03\n\x05Issue\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04hash\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12\"\n\x08severity\x18\x05 \x01(\x0e\x32\x10.warden.Severity\x12!\n\x05state\x18\x06 \x01(\x0e\x32\x12.warden.IssueState\x12\x11\n\tfile_path\x18\x07 \x01(\t\x12\x13\n\x0bline_number\x18\x08 \x01(\x05\x12\x14\n\x0c\x63ode_snippet\x18\t \x01(\t\x12\x10\n\x08\x66rame_id\x18\n \x01(\t\x12\x16\n\x0e\x66irst_detected\x18\x0b \x01(\t\x12\x11\n\tlast_seen\x18\x0c \x01(\t\x12\x13\n\x0bresolved_at\x18\r \x01(\t\x12\x13\n\x0bresolved_by\x18\x0e \x01(\t\x12\x15\n\rsuppressed_at\x18\x0f \x01(\t\x12\x15\n\rsuppressed_by\x18\x10 \x01(\t\x12\x1a\n\x12suppression_reason\x18\x11 \x01(\t\x12\x18\n\x10occurrence_count\x18\x12 \x01(\x05\x12-\n\x08metadata\x18\x13 \x03(\x0b\x32\x1b.warden.Issue.MetadataEntry\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xa4\x01\n\x0bIssueFilter\x12\"\n\x06states\x18\x01 \x03(\x0e\x32\x12.warden.IssueState\x12$\n\nseverities\x18\x02 \x03(\x0e\x32\x10.warden.Severity\x12\x11\n\tframe_ids\x18\x03 \x03(\t\x12\x19\n\x11\x66ile_path_pattern\x18\x04 \x01(\t\x12\r\n\x05limit\x18\x05 \x01(\x05\x12\x0e\n\x06offset\x18\x06 \x01(\x05\"W\n\tIssueList\x12\x1d\n\x06issues\x18\x01 \x03(\x0b\x32\r.warden.Issue\x12\x13\n\x0btotal_count\x18\x02 \x01(\x05\x12\x16\n\x0e\x66iltered_count\x18\x03 \x01(\x05\" \n\x0cIssueRequest\x12\x10\n\x08issue_id\x18\x01 \x01(\t\" \n\x10IssueHashRequest\x12\x0c\n\x04hash\x18\x01 \x01(\t\"F\n\x12IssueActionRequest\x12\x10\n\x08issue_id\x18\x01 \x01(\t\x12\r\n\x05\x61\x63tor\x18\x02 \x01(\t\x12\x0f\n\x07\x63omment\x18\x03 \x01(\t\"[\n\x13IssueActionResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x1c\n\x05issue\x18\x02 \x01(\x0b\x32\r.warden.Issue\x12\x15\n\rerror_message\x18\x03 \x01(\t\"\xdd\x02\n\nIssueStats\x12\r\n\x05total\x18\x01 \x01(\x05\x12\x0c\n\x04open\x18\x02 \x01(\x05\x12\x10\n\x08resolved\x18\x03 \x01(\x05\x12\x12\n\nsuppressed\x18\x04 \x01(\x05\x12\x10\n\x08\x63ritical\x18\x05 \x01(\x05\x12\x0c\n\x04high\x18\x06 \x01(\x05\x12\x0e\n\x06medium\x18\x07 \x01(\x05\x12\x0b\n\x03low\x18\x08 \x01(\x05\x12\x0c\n\x04info\x18\t \x01(\x05\x12\x31\n\x08\x62y_frame\x18\n \x03(\x0b\x32\x1f.warden.IssueStats.ByFrameEntry\x12/\n\x07\x62y_file\x18\x0b \x03(\x0b\x32\x1e.warden.IssueStats.ByFileEntry\x1a.\n\x0c\x42yFrameEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x05:\x02\x38\x01\x1a-\n\x0b\x42yFileEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x05:\x02\x38\x01\"8\n\x0cIssueHistory\x12(\n\tsnapshots\x18\x01 \x03(\x0b\x32\x15.warden.IssueSnapshot\"\xc2\x01\n\rIssueSnapshot\x12\x13\n\x0bsnapshot_id\x18\x01 \x01(\t\x12\x11\n\ttimestamp\x18\x02 \x01(\t\x12\x0e\n\x06run_id\x18\x03 \x01(\t\x12\x14\n\x0ctotal_issues\x18\x04 \x01(\x05\x12\x12\n\nnew_issues\x18\x05 \x01(\x05\x12\x17\n\x0fresolved_issues\x18\x06 \x01(\x05\x12\x17\n\x0freopened_issues\x18\x07 \x01(\x05\x12\x1d\n\x06issues\x18\x08 \x03(\x0b\x32\r.warden.Issue\"x\n\x15\x41nalyzeResultsRequest\x12&\n\x06result\x18\x01 \x01(\x0b\x32\x16.warden.PipelineResult\x12\x12\n\nproject_id\x18\x02 \x01(\t\x12\x0e\n\x06\x62ranch\x18\x03 \x01(\t\x12\x13\n\x0b\x63ommit_hash\x18\x04 \x01(\t\"\xe4\x02\n\x0e\x41nalysisResult\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12%\n\x05trend\x18\x02 \x01(\x0e\x32\x16.warden.TrendDirection\x12\x15\n\rquality_score\x18\x03 \x01(\x02\x12\x12\n\nnew_issues\x18\x04 \x01(\x05\x12\x17\n\x0fresolved_issues\x18\x05 \x01(\x05\x12\x17\n\x0freopened_issues\x18\x06 \x01(\x05\x12\x19\n\x11persistent_issues\x18\x07 \x01(\x05\x12.\n\x0ftrending_issues\x18\x08 \x03(\x0b\x32\x15.warden.TrendingIssue\x12\'\n\x0b\x66rame_stats\x18\t \x01(\x0b\x32\x12.warden.FrameStats\x12-\n\x0eseverity_stats\x18\n \x01(\x0b\x32\x15.warden.SeverityStats\x12\x1a\n\x12\x61nalysis_timestamp\x18\x0b \x01(\t\"s\n\rTrendingIssue\x12\x12\n\nissue_hash\x18\x01 \x01(\t\x12\r\n\x05title\x18\x02 \x01(\t\x12\x18\n\x10occurrence_count\x18\x03 \x01(\x05\x12%\n\x05trend\x18\x04 \x01(\x0e\x32\x16.warden.TrendDirection\"{\n\nFrameStats\x12,\n\x05stats\x18\x01 \x03(\x0b\x32\x1d.warden.FrameStats.StatsEntry\x1a?\n\nStatsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12 \n\x05value\x18\x02 \x01(\x0b\x32\x11.warden.FrameStat:\x02\x38\x01\"\xb7\x01\n\tFrameStat\x12\x10\n\x08\x66rame_id\x18\x01 \x01(\t\x12\x12\n\nframe_name\x18\x02 \x01(\t\x12\x16\n\x0etotal_findings\x18\x03 \x01(\x05\x12\x10\n\x08\x63ritical\x18\x04 \x01(\x05\x12\x0c\n\x04high\x18\x05 \x01(\x05\x12\x0e\n\x06medium\x18\x06 \x01(\x05\x12\x0b\n\x03low\x18\x07 \x01(\x05\x12\x14\n\x0c\x61vg_severity\x18\x08 \x01(\x02\x12\x19\n\x11\x65xecution_time_ms\x18\t \x01(\x03\"r\n\rSeverityStats\x12\x10\n\x08\x63ritical\x18\x01 \x01(\x05\x12\x0c\n\x04high\x18\x02 \x01(\x05\x12\x0e\n\x06medium\x18\x03 \x01(\x05\x12\x0b\n\x03low\x18\x04 \x01(\x05\x12\x0c\n\x04info\x18\x05 \x01(\x05\x12\x16\n\x0eweighted_score\x18\x06 \x01(\x02\"\x1d\n\x0cTrendRequest\x12\r\n\x05limit\x18\x01 \x01(\x05\"b\n\rTrendResponse\x12-\n\roverall_trend\x18\x01 \x01(\x0e\x32\x16.warden.TrendDirection\x12\"\n\x06points\x18\x02 \x03(\x0b\x32\x12.warden.TrendPoint\"L\n\nTrendPoint\x12\x11\n\ttimestamp\x18\x01 \x01(\t\x12\x14\n\x0ctotal_issues\x18\x02 \x01(\x05\x12\x15\n\rquality_score\x18\x03 \x01(\x02\"\xa6\x01\n\x14QualityScoreResponse\x12\r\n\x05score\x18\x01 \x01(\x02\x12\r\n\x05grade\x18\x02 \x01(\t\x12>\n\tbreakdown\x18\x03 \x03(\x0b\x32+.warden.QualityScoreResponse.BreakdownEntry\x1a\x30\n\x0e\x42reakdownEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x02:\x02\x38\x01\"\xd7\x01\n\rReportRequest\x12\x0e\n\x06run_id\x18\x01 \x01(\t\x12\x13\n\x0boutput_path\x18\x02 \x01(\t\x12\x14\n\x0cproject_name\x18\x03 \x01(\t\x12\x0e\n\x06\x62ranch\x18\x04 \x01(\t\x12\x13\n\x0b\x63ommit_hash\x18\x05 \x01(\t\x12\x35\n\x08metadata\x18\x06 \x03(\x0b\x32#.warden.ReportRequest.MetadataEntry\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x83\x01\n\x0eReportResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x11\n\treport_id\x18\x02 \x01(\t\x12\x11\n\tfile_path\x18\x03 \x01(\t\x12\x0f\n\x07\x63ontent\x18\x04 \x01(\t\x12\x12\n\nsize_bytes\x18\x05 \x01(\x03\x12\x15\n\rerror_message\x18\x06 \x01(\t\"(\n\x13ReportStatusRequest\x12\x11\n\treport_id\x18\x01 \x01(\t\"u\n\x14ReportStatusResponse\x12\x11\n\treport_id\x18\x01 \x01(\t\x12\x0e\n\x06status\x18\x02 \x01(\t\x12\x10\n\x08progress\x18\x03 \x01(\x02\x12\x11\n\tfile_path\x18\x04 \x01(\t\x12\x15\n\rerror_message\x18\x05 \x01(\t\"g\n\rSearchRequest\x12\r\n\x05query\x18\x01 \x01(\t\x12\x10\n\x08language\x18\x02 \x01(\t\x12\r\n\x05limit\x18\x03 \x01(\x05\x12\x11\n\tmin_score\x18\x04 \x01(\x02\x12\x13\n\x0b\x63hunk_types\x18\x05 \x03(\t\"a\n\x0cSearchResult\x12\"\n\x07results\x18\x01 \x03(\x0b\x32\x11.warden.CodeChunk\x12\x15\n\rtotal_matches\x18\x02 \x01(\x05\x12\x16\n\x0esearch_time_ms\x18\x03 \x01(\x03\"\x93\x02\n\tCodeChunk\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\tfile_path\x18\x02 \x01(\t\x12\x12\n\nchunk_type\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x0f\n\x07\x63ontent\x18\x05 \x01(\t\x12\x12\n\nstart_line\x18\x06 \x01(\x05\x12\x10\n\x08\x65nd_line\x18\x07 \x01(\x05\x12\x10\n\x08language\x18\x08 \x01(\t\x12\x18\n\x10similarity_score\x18\t \x01(\x02\x12\x31\n\x08metadata\x18\n \x03(\x0b\x32\x1f.warden.CodeChunk.MetadataEntry\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"V\n\x12SimilarCodeRequest\x12\x0c\n\x04\x63ode\x18\x01 \x01(\t\x12\x10\n\x08language\x18\x02 \x01(\t\x12\r\n\x05limit\x18\x03 \x01(\x05\x12\x11\n\tmin_score\x18\x04 \x01(\x02\"F\n\x0cIndexRequest\x12\x0c\n\x04path\x18\x01 \x01(\t\x12\x15\n\rforce_reindex\x18\x02 \x01(\x08\x12\x11\n\tlanguages\x18\x03 \x03(\t\"{\n\rIndexResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x15\n\rfiles_indexed\x18\x02 \x01(\x05\x12\x16\n\x0e\x63hunks_created\x18\x03 \x01(\x05\x12\x13\n\x0b\x64uration_ms\x18\x04 \x01(\x03\x12\x15\n\rerror_message\x18\x05 \x01(\t\"\xd9\x02\n\nIndexStats\x12\x13\n\x0btotal_files\x18\x01 \x01(\x05\x12\x14\n\x0ctotal_chunks\x18\x02 \x01(\x05\x12\x44\n\x12\x63hunks_by_language\x18\x03 \x03(\x0b\x32(.warden.IndexStats.ChunksByLanguageEntry\x12<\n\x0e\x63hunks_by_type\x18\x04 \x03(\x0b\x32$.warden.IndexStats.ChunksByTypeEntry\x12\x14\n\x0clast_indexed\x18\x05 \x01(\t\x12\x18\n\x10index_size_bytes\x18\x06 \x01(\x03\x1a\x37\n\x15\x43hunksByLanguageEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x05:\x02\x38\x01\x1a\x33\n\x11\x43hunksByTypeEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x05:\x02\x38\x01\"}\n\x0f\x44iscoverRequest\x12\x0c\n\x04path\x18\x01 \x01(\t\x12\x11\n\tmax_depth\x18\x02 \x01(\x05\x12\x15\n\ruse_gitignore\x18\x03 \x01(\x08\x12\x18\n\x10include_patterns\x18\x04 \x03(\t\x12\x18\n\x10\x65xclude_patterns\x18\x05 \x03(\t\"\xe4\x01\n\x10\x44iscoverResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x13\n\x0btotal_files\x18\x02 \x01(\x05\x12\x18\n\x10\x61nalyzable_files\x18\x03 \x01(\x05\x12%\n\x05\x66iles\x18\x04 \x03(\x0b\x32\x16.warden.DiscoveredFile\x12-\n\nframeworks\x18\x05 \x03(\x0b\x32\x19.warden.DetectedFramework\x12#\n\x05stats\x18\x06 \x01(\x0b\x32\x14.warden.ProjectStats\x12\x15\n\rerror_message\x18\x07 \x01(\t\"\x94\x01\n\x0e\x44iscoveredFile\x12\x0c\n\x04path\x18\x01 \x01(\t\x12#\n\tfile_type\x18\x02 \x01(\x0e\x32\x10.warden.FileType\x12\x12\n\nsize_bytes\x18\x03 \x01(\x03\x12\x12\n\nline_count\x18\x04 \x01(\x05\x12\x15\n\ris_analyzable\x18\x05 \x01(\x08\x12\x10\n\x08language\x18\x06 \x01(\t\"1\n\x0e\x46ileTypeFilter\x12\x1f\n\x05types\x18\x01 \x03(\x0e\x32\x10.warden.FileType\"o\n\x11\x44\x65tectedFramework\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\x12\x10\n\x08language\x18\x03 \x01(\t\x12\x12\n\nconfidence\x18\x04 \x01(\x02\x12\x15\n\rdetected_from\x18\x05 \x01(\t\"\xce\x02\n\x0cProjectStats\x12\x13\n\x0btotal_files\x18\x01 \x01(\x05\x12\x13\n\x0btotal_lines\x18\x02 \x01(\x05\x12\x18\n\x10total_size_bytes\x18\x03 \x01(\x03\x12\x44\n\x11\x66iles_by_language\x18\x04 \x03(\x0b\x32).warden.ProjectStats.FilesByLanguageEntry\x12\x44\n\x11lines_by_language\x18\x05 \x03(\x0b\x32).warden.ProjectStats.LinesByLanguageEntry\x1a\x36\n\x14\x46ilesByLanguageEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x05:\x02\x38\x01\x1a\x36\n\x14LinesByLanguageEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x05:\x02\x38\x01\"{\n\x11LlmAnalyzeRequest\x12\x0c\n\x04\x63ode\x18\x01 \x01(\t\x12\x0e\n\x06prompt\x18\x02 \x01(\t\x12\x10\n\x08provider\x18\x03 \x01(\t\x12\r\n\x05model\x18\x04 \x01(\t\x12\x13\n\x0btemperature\x18\x05 \x01(\x02\x12\x12\n\nmax_tokens\x18\x06 \x01(\x05\"\xab\x01\n\x10LlmAnalyzeResult\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x10\n\x08response\x18\x02 \x01(\t\x12\x15\n\rprovider_used\x18\x03 \x01(\t\x12\x12\n\nmodel_used\x18\x04 \x01(\t\x12\x13\n\x0btokens_used\x18\x05 \x01(\x05\x12\x13\n\x0b\x64uration_ms\x18\x06 \x01(\x03\x12\x1f\n\x05\x65rror\x18\x07 \x01(\x0b\x32\x10.warden.LlmError\";\n\x08LlmError\x12\x0c\n\x04\x63ode\x18\x01 \x01(\t\x12\x0f\n\x07message\x18\x02 \x01(\t\x12\x10\n\x08provider\x18\x03 \x01(\t\"7\n\x13TestProviderRequest\x12\x10\n\x08provider\x18\x01 \x01(\t\x12\x0e\n\x06prompt\x18\x02 \x01(\t\"s\n\x14TestProviderResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x10\n\x08provider\x18\x02 \x01(\t\x12\r\n\x05model\x18\x03 \x01(\t\x12\x12\n\nlatency_ms\x18\x04 \x01(\x03\x12\x15\n\rerror_message\x18\x05 \x01(\t\"*\n\x16\x41vailableModelsRequest\x12\x10\n\x08provider\x18\x01 \x01(\t\";\n\x17\x41vailableModelsResponse\x12 \n\x06models\x18\x01 \x03(\x0b\x32\x10.warden.LlmModel\"]\n\x08LlmModel\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x10\n\x08provider\x18\x03 \x01(\t\x12\x12\n\nmax_tokens\x18\x04 \x01(\x05\x12\x11\n\tavailable\x18\x05 \x01(\x08\"\x99\x01\n\x18ValidateLlmConfigRequest\x12\x10\n\x08provider\x18\x01 \x01(\t\x12<\n\x06\x63onfig\x18\x02 \x03(\x0b\x32,.warden.ValidateLlmConfigRequest.ConfigEntry\x1a-\n\x0b\x43onfigEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"L\n\x19ValidateLlmConfigResponse\x12\r\n\x05valid\x18\x01 \x01(\x08\x12\x0e\n\x06\x65rrors\x18\x02 \x03(\t\x12\x10\n\x08warnings\x18\x03 \x03(\t\"1\n\x0e\x43leanupRequest\x12\x0c\n\x04path\x18\x01 \x01(\t\x12\x11\n\tanalyzers\x18\x02 \x03(\t\"\x93\x01\n\rCleanupResult\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12.\n\x0bsuggestions\x18\x02 \x03(\x0b\x32\x19.warden.CleanupSuggestion\x12\x15\n\rcleanup_score\x18\x03 \x01(\x02\x12\x13\n\x0b\x64uration_ms\x18\x04 \x01(\x03\x12\x15\n\rerror_message\x18\x05 \x01(\t\"\xce\x01\n\x11\x43leanupSuggestion\x12\n\n\x02id\x18\x01 \x01(\t\x12\x10\n\x08\x61nalyzer\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12\x11\n\tfile_path\x18\x05 \x01(\t\x12\x13\n\x0bline_number\x18\x06 \x01(\x05\x12\x14\n\x0c\x63ode_snippet\x18\x07 \x01(\t\x12\x15\n\rsuggested_fix\x18\x08 \x01(\t\x12\"\n\x08priority\x18\t \x01(\x0e\x32\x10.warden.Severity\"\xbe\x01\n\x14\x43leanupScoreResponse\x12\x15\n\roverall_score\x18\x01 \x01(\x02\x12I\n\x0f\x61nalyzer_scores\x18\x02 \x03(\x0b\x32\x30.warden.CleanupScoreResponse.AnalyzerScoresEntry\x12\r\n\x05grade\x18\x03 \x01(\t\x1a\x35\n\x13\x41nalyzerScoresEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x02:\x02\x38\x01\"8\n\x14\x46ortificationRequest\x12\x0c\n\x04path\x18\x01 \x01(\t\x12\x12\n\nfortifiers\x18\x02 \x03(\t\"\xa0\x01\n\x13\x46ortificationResult\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x34\n\x0bsuggestions\x18\x02 \x03(\x0b\x32\x1f.warden.FortificationSuggestion\x12\x16\n\x0esecurity_score\x18\x03 \x01(\x02\x12\x13\n\x0b\x64uration_ms\x18\x04 \x01(\x03\x12\x15\n\rerror_message\x18\x05 \x01(\t\"\xea\x01\n\x17\x46ortificationSuggestion\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\tfortifier\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12\x11\n\tfile_path\x18\x05 \x01(\t\x12\x13\n\x0bline_number\x18\x06 \x01(\x05\x12\x15\n\roriginal_code\x18\x07 \x01(\t\x12\x16\n\x0esuggested_code\x18\x08 \x01(\t\x12\x11\n\trationale\x18\t \x01(\t\x12\"\n\x08priority\x18\n \x01(\x0e\x32\x10.warden.Severity\"C\n\x19\x41pplyFortificationRequest\x12\x15\n\rsuggestion_id\x18\x01 \x01(\t\x12\x0f\n\x07\x64ry_run\x18\x02 \x01(\x08\"e\n\x1a\x41pplyFortificationResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x11\n\tfile_path\x18\x02 \x01(\t\x12\x0c\n\x04\x64iff\x18\x03 \x01(\t\x12\x15\n\rerror_message\x18\x04 \x01(\t\"\xd9\x01\n\x15SecurityScoreResponse\x12\x15\n\roverall_score\x18\x01 \x01(\x02\x12J\n\x0f\x63\x61tegory_scores\x18\x02 \x03(\x0b\x32\x31.warden.SecurityScoreResponse.CategoryScoresEntry\x12\x17\n\x0fvulnerabilities\x18\x03 \x03(\t\x12\r\n\x05grade\x18\x04 \x01(\t\x1a\x35\n\x13\x43\x61tegoryScoresEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x02:\x02\x38\x01\"\xb8\x01\n\x0bSuppression\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0f\n\x07rule_id\x18\x02 \x01(\t\x12\x11\n\tfile_path\x18\x03 \x01(\t\x12\x13\n\x0bline_number\x18\x04 \x01(\x05\x12\x15\n\rjustification\x18\x05 \x01(\t\x12\x12\n\ncreated_by\x18\x06 \x01(\t\x12\x12\n\ncreated_at\x18\x07 \x01(\t\x12\x12\n\nexpires_at\x18\x08 \x01(\t\x12\x11\n\tis_global\x18\t \x01(\x08\"\xa2\x01\n\x15\x41\x64\x64SuppressionRequest\x12\x0f\n\x07rule_id\x18\x01 \x01(\t\x12\x11\n\tfile_path\x18\x02 \x01(\t\x12\x13\n\x0bline_number\x18\x03 \x01(\x05\x12\x15\n\rjustification\x18\x04 \x01(\t\x12\x12\n\ncreated_by\x18\x05 \x01(\t\x12\x12\n\nexpires_at\x18\x06 \x01(\t\x12\x11\n\tis_global\x18\x07 \x01(\x08\"j\n\x16\x41\x64\x64SuppressionResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12(\n\x0bsuppression\x18\x02 \x01(\x0b\x32\x13.warden.Suppression\x12\x15\n\rerror_message\x18\x03 \x01(\t\"2\n\x18RemoveSuppressionRequest\x12\x16\n\x0esuppression_id\x18\x01 \x01(\t\"C\n\x19RemoveSuppressionResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x15\n\rerror_message\x18\x02 \x01(\t\"Q\n\x0fSuppressionList\x12)\n\x0csuppressions\x18\x01 \x03(\x0b\x32\x13.warden.Suppression\x12\x13\n\x0btotal_count\x18\x02 \x01(\x05\"R\n\x17\x43heckSuppressionRequest\x12\x0f\n\x07rule_id\x18\x01 \x01(\t\x12\x11\n\tfile_path\x18\x02 \x01(\t\x12\x13\n\x0bline_number\x18\x03 \x01(\x05\"k\n\x18\x43heckSuppressionResponse\x12\x15\n\ris_suppressed\x18\x01 \x01(\x08\x12(\n\x0bsuppression\x18\x02 \x01(\x0b\x32\x13.warden.Suppression\x12\x0e\n\x06reason\x18\x03 \x01(\t\"\x83\x01\n\x13UpdateConfigRequest\x12;\n\x08settings\x18\x01 \x03(\x0b\x32).warden.UpdateConfigRequest.SettingsEntry\x1a/\n\rSettingsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\">\n\x14UpdateConfigResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x15\n\rerror_message\x18\x02 \x01(\t\"=\n\x18UpdateFrameStatusRequest\x12\x10\n\x08\x66rame_id\x18\x01 \x01(\t\x12\x0f\n\x07\x65nabled\x18\x02 \x01(\x08\"a\n\x19UpdateFrameStatusResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x1c\n\x05\x66rame\x18\x02 \x01(\x0b\x32\r.warden.Frame\x12\x15\n\rerror_message\x18\x03 \x01(\t\"2\n\x0f\x43lassifyRequest\x12\x0c\n\x04\x63ode\x18\x01 \x01(\t\x12\x11\n\tfile_path\x18\x02 \x01(\t\"\xa2\x02\n\x0e\x43lassifyResult\x12\x1c\n\x14has_async_operations\x18\x01 \x01(\x08\x12\x16\n\x0ehas_user_input\x18\x02 \x01(\x08\x12\x1f\n\x17has_database_operations\x18\x03 \x01(\x08\x12\x19\n\x11has_network_calls\x18\x04 \x01(\x08\x12\x1b\n\x13has_file_operations\x18\x05 \x01(\x08\x12\x1a\n\x12has_authentication\x18\x06 \x01(\x08\x12\x18\n\x10has_cryptography\x18\x07 \x01(\x08\x12\x1b\n\x13\x64\x65tected_frameworks\x18\x08 \x03(\t\x12\x1a\n\x12recommended_frames\x18\t \x03(\t\x12\x12\n\nconfidence\x18\n \x01(\x02\"{\n\x05\x46rame\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x10\n\x08priority\x18\x04 \x01(\x05\x12\x12\n\nis_blocker\x18\x05 \x01(\x08\x12\x0f\n\x07\x65nabled\x18\x06 \x01(\x08\x12\x0c\n\x04tags\x18\x07 \x03(\t\"*\n\tFrameList\x12\x1d\n\x06\x66rames\x18\x01 \x03(\x0b\x32\r.warden.Frame\"[\n\x08Provider\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x11\n\tavailable\x18\x03 \x01(\x08\x12\x12\n\nis_default\x18\x04 \x01(\x08\x12\x0e\n\x06status\x18\x05 \x01(\t\"M\n\x0cProviderList\x12#\n\tproviders\x18\x01 \x03(\x0b\x32\x10.warden.Provider\x12\x18\n\x10\x64\x65\x66\x61ult_provider\x18\x02 \x01(\t\"\xaa\x02\n\x15\x43onfigurationResponse\x12\x14\n\x0cproject_root\x18\x01 \x01(\t\x12\x13\n\x0b\x63onfig_file\x18\x02 \x01(\t\x12\x16\n\x0e\x61\x63tive_profile\x18\x03 \x01(\t\x12+\n\x10\x61vailable_frames\x18\x04 \x01(\x0b\x32\x11.warden.FrameList\x12\x31\n\x13\x61vailable_providers\x18\x05 \x01(\x0b\x32\x14.warden.ProviderList\x12=\n\x08settings\x18\x06 \x03(\x0b\x32+.warden.ConfigurationResponse.SettingsEntry\x1a/\n\rSettingsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xb9\x01\n\x0eHealthResponse\x12\x0f\n\x07healthy\x18\x01 \x01(\x08\x12\x0f\n\x07version\x18\x02 \x01(\t\x12\x16\n\x0euptime_seconds\x18\x03 \x01(\x03\x12:\n\ncomponents\x18\x04 \x03(\x0b\x32&.warden.HealthResponse.ComponentsEntry\x1a\x31\n\x0f\x43omponentsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x08:\x02\x38\x01\"\x90\x01\n\x0eStatusResponse\x12\x0f\n\x07running\x18\x01 \x01(\x08\x12\x18\n\x10\x61\x63tive_pipelines\x18\x02 \x01(\x05\x12\x13\n\x0btotal_scans\x18\x03 \x01(\x03\x12\x16\n\x0etotal_findings\x18\x04 \x01(\x03\x12\x11\n\tmemory_mb\x18\x05 \x01(\x03\x12\x13\n\x0b\x63pu_percent\x18\x06 \x01(\x02\"\xc1\x01\n\x0fPipelineRequest\x12\x0c\n\x04path\x18\x01 \x01(\t\x12\x0e\n\x06\x66rames\x18\x02 \x03(\t\x12\x10\n\x08parallel\x18\x03 \x01(\x08\x12\x17\n\x0ftimeout_seconds\x18\x04 \x01(\x05\x12\x35\n\x07options\x18\x05 \x03(\x0b\x32$.warden.PipelineRequest.OptionsEntry\x1a.\n\x0cOptionsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xda\x02\n\x0ePipelineResult\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0e\n\x06run_id\x18\x02 \x01(\t\x12\x16\n\x0etotal_findings\x18\x03 \x01(\x05\x12\x16\n\x0e\x63ritical_count\x18\x04 \x01(\x05\x12\x12\n\nhigh_count\x18\x05 \x01(\x05\x12\x14\n\x0cmedium_count\x18\x06 \x01(\x05\x12\x11\n\tlow_count\x18\x07 \x01(\x05\x12!\n\x08\x66indings\x18\x08 \x03(\x0b\x32\x0f.warden.Finding\x12-\n\x0e\x66ortifications\x18\t \x03(\x0b\x32\x15.warden.Fortification\x12#\n\tcleanings\x18\n \x03(\x0b\x32\x10.warden.Cleaning\x12\x13\n\x0b\x64uration_ms\x18\x0b \x01(\x03\x12\x17\n\x0f\x66rames_executed\x18\x0c \x03(\t\x12\x15\n\rerror_message\x18\r \x01(\t\"\xdf\x01\n\rPipelineEvent\x12\x12\n\nevent_type\x18\x01 \x01(\t\x12\r\n\x05stage\x18\x02 \x01(\t\x12\x10\n\x08progress\x18\x03 \x01(\x02\x12\x0f\n\x07message\x18\x04 \x01(\t\x12 \n\x07\x66inding\x18\x05 \x01(\x0b\x32\x0f.warden.Finding\x12,\n\rfortification\x18\x06 \x01(\x0b\x32\x15.warden.Fortification\x12\"\n\x08\x63leaning\x18\x07 \x01(\x0b\x32\x10.warden.Cleaning\x12\x14\n\x0ctimestamp_ms\x18\x08 \x01(\x03*[\n\x08Severity\x12\x18\n\x14SEVERITY_UNSPECIFIED\x10\x00\x12\x0c\n\x08\x43RITICAL\x10\x01\x12\x08\n\x04HIGH\x10\x02\x12\n\n\x06MEDIUM\x10\x03\x12\x07\n\x03LOW\x10\x04\x12\x08\n\x04INFO\x10\x05*_\n\nIssueState\x12\x1b\n\x17ISSUE_STATE_UNSPECIFIED\x10\x00\x12\x08\n\x04OPEN\x10\x01\x12\x0c\n\x08RESOLVED\x10\x02\x12\x0e\n\nSUPPRESSED\x10\x03\x12\x0c\n\x08REOPENED\x10\x04*Q\n\x0eTrendDirection\x12\x15\n\x11TREND_UNSPECIFIED\x10\x00\x12\r\n\tIMPROVING\x10\x01\x12\n\n\x06STABLE\x10\x02\x12\r\n\tDEGRADING\x10\x03*\xc2\x01\n\x08\x46ileType\x12\x19\n\x15\x46ILE_TYPE_UNSPECIFIED\x10\x00\x12\n\n\x06PYTHON\x10\x01\x12\x0e\n\nJAVASCRIPT\x10\x02\x12\x0e\n\nTYPESCRIPT\x10\x03\x12\x08\n\x04JAVA\x10\x04\x12\n\n\x06\x43SHARP\x10\x05\x12\x06\n\x02GO\x10\x06\x12\x08\n\x04RUST\x10\x07\x12\x07\n\x03\x43PP\x10\x08\x12\x08\n\x04RUBY\x10\t\x12\x07\n\x03PHP\x10\n\x12\n\n\x06KOTLIN\x10\x0b\x12\t\n\x05SWIFT\x10\x0c\x12\t\n\x05SCALA\x10\r\x12\t\n\x05OTHER\x10\x63\x32\xa4\x1b\n\rWardenService\x12\x42\n\x0f\x45xecutePipeline\x12\x17.warden.PipelineRequest\x1a\x16.warden.PipelineResult\x12I\n\x15\x45xecutePipelineStream\x12\x17.warden.PipelineRequest\x1a\x15.warden.PipelineEvent0\x01\x12\x36\n\x0cGetAllIssues\x12\x13.warden.IssueFilter\x1a\x11.warden.IssueList\x12\x37\n\rGetOpenIssues\x12\x13.warden.IssueFilter\x1a\x11.warden.IssueList\x12\x39\n\x0eGetIssueByHash\x12\x18.warden.IssueHashRequest\x1a\r.warden.Issue\x12G\n\x0cResolveIssue\x12\x1a.warden.IssueActionRequest\x1a\x1b.warden.IssueActionResponse\x12H\n\rSuppressIssue\x12\x1a.warden.IssueActionRequest\x1a\x1b.warden.IssueActionResponse\x12\x46\n\x0bReopenIssue\x12\x1a.warden.IssueActionRequest\x1a\x1b.warden.IssueActionResponse\x12\x36\n\x0fGetIssueHistory\x12\r.warden.Empty\x1a\x14.warden.IssueHistory\x12\x32\n\rGetIssueStats\x12\r.warden.Empty\x1a\x12.warden.IssueStats\x12G\n\x0e\x41nalyzeResults\x12\x1d.warden.AnalyzeResultsRequest\x1a\x16.warden.AnalysisResult\x12\x38\n\tGetTrends\x12\x14.warden.TrendRequest\x1a\x15.warden.TrendResponse\x12\x32\n\rGetFrameStats\x12\r.warden.Empty\x1a\x12.warden.FrameStats\x12\x38\n\x10GetSeverityStats\x12\r.warden.Empty\x1a\x15.warden.SeverityStats\x12>\n\x0fGetQualityScore\x12\r.warden.Empty\x1a\x1c.warden.QualityScoreResponse\x12\x43\n\x12GenerateHtmlReport\x12\x15.warden.ReportRequest\x1a\x16.warden.ReportResponse\x12\x42\n\x11GeneratePdfReport\x12\x15.warden.ReportRequest\x1a\x16.warden.ReportResponse\x12\x43\n\x12GenerateJsonReport\x12\x15.warden.ReportRequest\x1a\x16.warden.ReportResponse\x12L\n\x0fGetReportStatus\x12\x1b.warden.ReportStatusRequest\x1a\x1c.warden.ReportStatusResponse\x12\x39\n\nSearchCode\x12\x15.warden.SearchRequest\x1a\x14.warden.SearchResult\x12\x45\n\x11SearchSimilarCode\x12\x1a.warden.SimilarCodeRequest\x1a\x14.warden.SearchResult\x12\x42\n\x13SearchByDescription\x12\x15.warden.SearchRequest\x1a\x14.warden.SearchResult\x12;\n\x0cIndexProject\x12\x14.warden.IndexRequest\x1a\x15.warden.IndexResponse\x12\x32\n\rGetIndexStats\x12\r.warden.Empty\x1a\x12.warden.IndexStats\x12\x32\n\nClearIndex\x12\r.warden.Empty\x1a\x15.warden.IndexResponse\x12\x42\n\rDiscoverFiles\x12\x17.warden.DiscoverRequest\x1a\x18.warden.DiscoverResponse\x12\x42\n\x0eGetFilesByType\x12\x16.warden.FileTypeFilter\x1a\x18.warden.DiscoverResponse\x12\x45\n\x10\x44\x65tectFrameworks\x12\x17.warden.DiscoverRequest\x1a\x18.warden.DiscoverResponse\x12\x36\n\x0fGetProjectStats\x12\r.warden.Empty\x1a\x14.warden.ProjectStats\x12\x45\n\x0e\x41nalyzeWithLlm\x12\x19.warden.LlmAnalyzeRequest\x1a\x18.warden.LlmAnalyzeResult\x12?\n\x0c\x43lassifyCode\x12\x17.warden.ClassifyRequest\x1a\x16.warden.ClassifyResult\x12L\n\x0fTestLlmProvider\x12\x1b.warden.TestProviderRequest\x1a\x1c.warden.TestProviderResponse\x12U\n\x12GetAvailableModels\x12\x1e.warden.AvailableModelsRequest\x1a\x1f.warden.AvailableModelsResponse\x12X\n\x11ValidateLlmConfig\x12 .warden.ValidateLlmConfigRequest\x1a!.warden.ValidateLlmConfigResponse\x12?\n\x0e\x41nalyzeCleanup\x12\x16.warden.CleanupRequest\x1a\x15.warden.CleanupResult\x12\x46\n\x15GetCleanupSuggestions\x12\x16.warden.CleanupRequest\x1a\x15.warden.CleanupResult\x12>\n\x0fGetCleanupScore\x12\r.warden.Empty\x1a\x1c.warden.CleanupScoreResponse\x12X\n\x1bGetFortificationSuggestions\x12\x1c.warden.FortificationRequest\x1a\x1b.warden.FortificationResult\x12[\n\x12\x41pplyFortification\x12!.warden.ApplyFortificationRequest\x1a\".warden.ApplyFortificationResponse\x12@\n\x10GetSecurityScore\x12\r.warden.Empty\x1a\x1d.warden.SecurityScoreResponse\x12O\n\x0e\x41\x64\x64Suppression\x12\x1d.warden.AddSuppressionRequest\x1a\x1e.warden.AddSuppressionResponse\x12X\n\x11RemoveSuppression\x12 .warden.RemoveSuppressionRequest\x1a!.warden.RemoveSuppressionResponse\x12\x39\n\x0fGetSuppressions\x12\r.warden.Empty\x1a\x17.warden.SuppressionList\x12U\n\x10\x43heckSuppression\x12\x1f.warden.CheckSuppressionRequest\x1a .warden.CheckSuppressionResponse\x12\x36\n\x12GetAvailableFrames\x12\r.warden.Empty\x1a\x11.warden.FrameList\x12<\n\x15GetAvailableProviders\x12\r.warden.Empty\x1a\x14.warden.ProviderList\x12@\n\x10GetConfiguration\x12\r.warden.Empty\x1a\x1d.warden.ConfigurationResponse\x12P\n\x13UpdateConfiguration\x12\x1b.warden.UpdateConfigRequest\x1a\x1c.warden.UpdateConfigResponse\x12X\n\x11UpdateFrameStatus\x12 .warden.UpdateFrameStatusRequest\x1a!.warden.UpdateFrameStatusResponse\x12\x34\n\x0bHealthCheck\x12\r.warden.Empty\x1a\x16.warden.HealthResponse\x12\x32\n\tGetStatus\x12\r.warden.Empty\x1a\x16.warden.StatusResponseB\x0e\xaa\x02\x0bWarden.Grpcb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'warden_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\252\002\013Warden.Grpc'
  _globals['_FINDING_METADATAENTRY']._loaded_options = None
  _globals['_FINDING_METADATAENTRY']._serialized_options = b'8\001'
  _globals['_ISSUE_METADATAENTRY']._loaded_options = None
  _globals['_ISSUE_METADATAENTRY']._serialized_options = b'8\001'
  _globals['_ISSUESTATS_BYFRAMEENTRY']._loaded_options = None
  _globals['_ISSUESTATS_BYFRAMEENTRY']._serialized_options = b'8\001'
  _globals['_ISSUESTATS_BYFILEENTRY']._loaded_options = None
  _globals['_ISSUESTATS_BYFILEENTRY']._serialized_options = b'8\001'
  _globals['_FRAMESTATS_STATSENTRY']._loaded_options = None
  _globals['_FRAMESTATS_STATSENTRY']._serialized_options = b'8\001'
  _globals['_QUALITYSCORERESPONSE_BREAKDOWNENTRY']._loaded_options = None
  _globals['_QUALITYSCORERESPONSE_BREAKDOWNENTRY']._serialized_options = b'8\001'
  _globals['_REPORTREQUEST_METADATAENTRY']._loaded_options = None
  _globals['_REPORTREQUEST_METADATAENTRY']._serialized_options = b'8\001'
  _globals['_CODECHUNK_METADATAENTRY']._loaded_options = None
  _globals['_CODECHUNK_METADATAENTRY']._serialized_options = b'8\001'
  _globals['_INDEXSTATS_CHUNKSBYLANGUAGEENTRY']._loaded_options = None
  _globals['_INDEXSTATS_CHUNKSBYLANGUAGEENTRY']._serialized_options = b'8\001'
  _globals['_INDEXSTATS_CHUNKSBYTYPEENTRY']._loaded_options = None
  _globals['_INDEXSTATS_CHUNKSBYTYPEENTRY']._serialized_options = b'8\001'
  _globals['_PROJECTSTATS_FILESBYLANGUAGEENTRY']._loaded_options = None
  _globals['_PROJECTSTATS_FILESBYLANGUAGEENTRY']._serialized_options = b'8\001'
  _globals['_PROJECTSTATS_LINESBYLANGUAGEENTRY']._loaded_options = None
  _globals['_PROJECTSTATS_LINESBYLANGUAGEENTRY']._serialized_options = b'8\001'
  _globals['_VALIDATELLMCONFIGREQUEST_CONFIGENTRY']._loaded_options = None
  _globals['_VALIDATELLMCONFIGREQUEST_CONFIGENTRY']._serialized_options = b'8\001'
  _globals['_CLEANUPSCORERESPONSE_ANALYZERSCORESENTRY']._loaded_options = None
  _globals['_CLEANUPSCORERESPONSE_ANALYZERSCORESENTRY']._serialized_options = b'8\001'
  _globals['_SECURITYSCORERESPONSE_CATEGORYSCORESENTRY']._loaded_options = None
  _globals['_SECURITYSCORERESPONSE_CATEGORYSCORESENTRY']._serialized_options = b'8\001'
  _globals['_UPDATECONFIGREQUEST_SETTINGSENTRY']._loaded_options = None
  _globals['_UPDATECONFIGREQUEST_SETTINGSENTRY']._serialized_options = b'8\001'
  _globals['_CONFIGURATIONRESPONSE_SETTINGSENTRY']._loaded_options = None
  _globals['_CONFIGURATIONRESPONSE_SETTINGSENTRY']._serialized_options = b'8\001'
  _globals['_HEALTHRESPONSE_COMPONENTSENTRY']._loaded_options = None
  _globals['_HEALTHRESPONSE_COMPONENTSENTRY']._serialized_options = b'8\001'
  _globals['_PIPELINEREQUEST_OPTIONSENTRY']._loaded_options = None
  _globals['_PIPELINEREQUEST_OPTIONSENTRY']._serialized_options = b'8\001'
  _globals['_SEVERITY']._serialized_start=12086
  _globals['_SEVERITY']._serialized_end=12177
  _globals['_ISSUESTATE']._serialized_start=12179
  _globals['_ISSUESTATE']._serialized_end=12274
  _globals['_TRENDDIRECTION']._serialized_start=12276
  _globals['_TRENDDIRECTION']._serialized_end=12357
  _globals['_FILETYPE']._serialized_start=12360
  _globals['_FILETYPE']._serialized_end=12554
  _globals['_EMPTY']._serialized_start=24
  _globals['_EMPTY']._serialized_end=31
  _globals['_FINDING']._serialized_start=34
  _globals['_FINDING']._serialized_end=388
  _globals['_FINDING_METADATAENTRY']._serialized_start=341
  _globals['_FINDING_METADATAENTRY']._serialized_end=388
  _globals['_FORTIFICATION']._serialized_start=391
  _globals['_FORTIFICATION']._serialized_end=596
  _globals['_CLEANING']._serialized_start=598
  _globals['_CLEANING']._serialized_end=712
  _globals['_ISSUE']._serialized_start=715
  _globals['_ISSUE']._serialized_end=1216
  _globals['_ISSUE_METADATAENTRY']._serialized_start=341
  _globals['_ISSUE_METADATAENTRY']._serialized_end=388
  _globals['_ISSUEFILTER']._serialized_start=1219
  _globals['_ISSUEFILTER']._serialized_end=1383
  _globals['_ISSUELIST']._serialized_start=1385
  _globals['_ISSUELIST']._serialized_end=1472
  _globals['_ISSUEREQUEST']._serialized_start=1474
  _globals['_ISSUEREQUEST']._serialized_end=1506
  _globals['_ISSUEHASHREQUEST']._serialized_start=1508
  _globals['_ISSUEHASHREQUEST']._serialized_end=1540
  _globals['_ISSUEACTIONREQUEST']._serialized_start=1542
  _globals['_ISSUEACTIONREQUEST']._serialized_end=1612
  _globals['_ISSUEACTIONRESPONSE']._serialized_start=1614
  _globals['_ISSUEACTIONRESPONSE']._serialized_end=1705
  _globals['_ISSUESTATS']._serialized_start=1708
  _globals['_ISSUESTATS']._serialized_end=2057
  _globals['_ISSUESTATS_BYFRAMEENTRY']._serialized_start=1964
  _globals['_ISSUESTATS_BYFRAMEENTRY']._serialized_end=2010
  _globals['_ISSUESTATS_BYFILEENTRY']._serialized_start=2012
  _globals['_ISSUESTATS_BYFILEENTRY']._serialized_end=2057
  _globals['_ISSUEHISTORY']._serialized_start=2059
  _globals['_ISSUEHISTORY']._serialized_end=2115
  _globals['_ISSUESNAPSHOT']._serialized_start=2118
  _globals['_ISSUESNAPSHOT']._serialized_end=2312
  _globals['_ANALYZERESULTSREQUEST']._serialized_start=2314
  _globals['_ANALYZERESULTSREQUEST']._serialized_end=2434
  _globals['_ANALYSISRESULT']._serialized_start=2437
  _globals['_ANALYSISRESULT']._serialized_end=2793
  _globals['_TRENDINGISSUE']._serialized_start=2795
  _globals['_TRENDINGISSUE']._serialized_end=2910
  _globals['_FRAMESTATS']._serialized_start=2912
  _globals['_FRAMESTATS']._serialized_end=3035
  _globals['_FRAMESTATS_STATSENTRY']._serialized_start=2972
  _globals['_FRAMESTATS_STATSENTRY']._serialized_end=3035
  _globals['_FRAMESTAT']._serialized_start=3038
  _globals['_FRAMESTAT']._serialized_end=3221
  _globals['_SEVERITYSTATS']._serialized_start=3223
  _globals['_SEVERITYSTATS']._serialized_end=3337
  _globals['_TRENDREQUEST']._serialized_start=3339
  _globals['_TRENDREQUEST']._serialized_end=3368
  _globals['_TRENDRESPONSE']._serialized_start=3370
  _globals['_TRENDRESPONSE']._serialized_end=3468
  _globals['_TRENDPOINT']._serialized_start=3470
  _globals['_TRENDPOINT']._serialized_end=3546
  _globals['_QUALITYSCORERESPONSE']._serialized_start=3549
  _globals['_QUALITYSCORERESPONSE']._serialized_end=3715
  _globals['_QUALITYSCORERESPONSE_BREAKDOWNENTRY']._serialized_start=3667
  _globals['_QUALITYSCORERESPONSE_BREAKDOWNENTRY']._serialized_end=3715
  _globals['_REPORTREQUEST']._serialized_start=3718
  _globals['_REPORTREQUEST']._serialized_end=3933
  _globals['_REPORTREQUEST_METADATAENTRY']._serialized_start=341
  _globals['_REPORTREQUEST_METADATAENTRY']._serialized_end=388
  _globals['_REPORTRESPONSE']._serialized_start=3936
  _globals['_REPORTRESPONSE']._serialized_end=4067
  _globals['_REPORTSTATUSREQUEST']._serialized_start=4069
  _globals['_REPORTSTATUSREQUEST']._serialized_end=4109
  _globals['_REPORTSTATUSRESPONSE']._serialized_start=4111
  _globals['_REPORTSTATUSRESPONSE']._serialized_end=4228
  _globals['_SEARCHREQUEST']._serialized_start=4230
  _globals['_SEARCHREQUEST']._serialized_end=4333
  _globals['_SEARCHRESULT']._serialized_start=4335
  _globals['_SEARCHRESULT']._serialized_end=4432
  _globals['_CODECHUNK']._serialized_start=4435
  _globals['_CODECHUNK']._serialized_end=4710
  _globals['_CODECHUNK_METADATAENTRY']._serialized_start=341
  _globals['_CODECHUNK_METADATAENTRY']._serialized_end=388
  _globals['_SIMILARCODEREQUEST']._serialized_start=4712
  _globals['_SIMILARCODEREQUEST']._serialized_end=4798
  _globals['_INDEXREQUEST']._serialized_start=4800
  _globals['_INDEXREQUEST']._serialized_end=4870
  _globals['_INDEXRESPONSE']._serialized_start=4872
  _globals['_INDEXRESPONSE']._serialized_end=4995
  _globals['_INDEXSTATS']._serialized_start=4998
  _globals['_INDEXSTATS']._serialized_end=5343
  _globals['_INDEXSTATS_CHUNKSBYLANGUAGEENTRY']._serialized_start=5235
  _globals['_INDEXSTATS_CHUNKSBYLANGUAGEENTRY']._serialized_end=5290
  _globals['_INDEXSTATS_CHUNKSBYTYPEENTRY']._serialized_start=5292
  _globals['_INDEXSTATS_CHUNKSBYTYPEENTRY']._serialized_end=5343
  _globals['_DISCOVERREQUEST']._serialized_start=5345
  _globals['_DISCOVERREQUEST']._serialized_end=5470
  _globals['_DISCOVERRESPONSE']._serialized_start=5473
  _globals['_DISCOVERRESPONSE']._serialized_end=5701
  _globals['_DISCOVEREDFILE']._serialized_start=5704
  _globals['_DISCOVEREDFILE']._serialized_end=5852
  _globals['_FILETYPEFILTER']._serialized_start=5854
  _globals['_FILETYPEFILTER']._serialized_end=5903
  _globals['_DETECTEDFRAMEWORK']._serialized_start=5905
  _globals['_DETECTEDFRAMEWORK']._serialized_end=6016
  _globals['_PROJECTSTATS']._serialized_start=6019
  _globals['_PROJECTSTATS']._serialized_end=6353
  _globals['_PROJECTSTATS_FILESBYLANGUAGEENTRY']._serialized_start=6243
  _globals['_PROJECTSTATS_FILESBYLANGUAGEENTRY']._serialized_end=6297
  _globals['_PROJECTSTATS_LINESBYLANGUAGEENTRY']._serialized_start=6299
  _globals['_PROJECTSTATS_LINESBYLANGUAGEENTRY']._serialized_end=6353
  _globals['_LLMANALYZEREQUEST']._serialized_start=6355
  _globals['_LLMANALYZEREQUEST']._serialized_end=6478
  _globals['_LLMANALYZERESULT']._serialized_start=6481
  _globals['_LLMANALYZERESULT']._serialized_end=6652
  _globals['_LLMERROR']._serialized_start=6654
  _globals['_LLMERROR']._serialized_end=6713
  _globals['_TESTPROVIDERREQUEST']._serialized_start=6715
  _globals['_TESTPROVIDERREQUEST']._serialized_end=6770
  _globals['_TESTPROVIDERRESPONSE']._serialized_start=6772
  _globals['_TESTPROVIDERRESPONSE']._serialized_end=6887
  _globals['_AVAILABLEMODELSREQUEST']._serialized_start=6889
  _globals['_AVAILABLEMODELSREQUEST']._serialized_end=6931
  _globals['_AVAILABLEMODELSRESPONSE']._serialized_start=6933
  _globals['_AVAILABLEMODELSRESPONSE']._serialized_end=6992
  _globals['_LLMMODEL']._serialized_start=6994
  _globals['_LLMMODEL']._serialized_end=7087
  _globals['_VALIDATELLMCONFIGREQUEST']._serialized_start=7090
  _globals['_VALIDATELLMCONFIGREQUEST']._serialized_end=7243
  _globals['_VALIDATELLMCONFIGREQUEST_CONFIGENTRY']._serialized_start=7198
  _globals['_VALIDATELLMCONFIGREQUEST_CONFIGENTRY']._serialized_end=7243
  _globals['_VALIDATELLMCONFIGRESPONSE']._serialized_start=7245
  _globals['_VALIDATELLMCONFIGRESPONSE']._serialized_end=7321
  _globals['_CLEANUPREQUEST']._serialized_start=7323
  _globals['_CLEANUPREQUEST']._serialized_end=7372
  _globals['_CLEANUPRESULT']._serialized_start=7375
  _globals['_CLEANUPRESULT']._serialized_end=7522
  _globals['_CLEANUPSUGGESTION']._serialized_start=7525
  _globals['_CLEANUPSUGGESTION']._serialized_end=7731
  _globals['_CLEANUPSCORERESPONSE']._serialized_start=7734
  _globals['_CLEANUPSCORERESPONSE']._serialized_end=7924
  _globals['_CLEANUPSCORERESPONSE_ANALYZERSCORESENTRY']._serialized_start=7871
  _globals['_CLEANUPSCORERESPONSE_ANALYZERSCORESENTRY']._serialized_end=7924
  _globals['_FORTIFICATIONREQUEST']._serialized_start=7926
  _globals['_FORTIFICATIONREQUEST']._serialized_end=7982
  _globals['_FORTIFICATIONRESULT']._serialized_start=7985
  _globals['_FORTIFICATIONRESULT']._serialized_end=8145
  _globals['_FORTIFICATIONSUGGESTION']._serialized_start=8148
  _globals['_FORTIFICATIONSUGGESTION']._serialized_end=8382
  _globals['_APPLYFORTIFICATIONREQUEST']._serialized_start=8384
  _globals['_APPLYFORTIFICATIONREQUEST']._serialized_end=8451
  _globals['_APPLYFORTIFICATIONRESPONSE']._serialized_start=8453
  _globals['_APPLYFORTIFICATIONRESPONSE']._serialized_end=8554
  _globals['_SECURITYSCORERESPONSE']._serialized_start=8557
  _globals['_SECURITYSCORERESPONSE']._serialized_end=8774
  _globals['_SECURITYSCORERESPONSE_CATEGORYSCORESENTRY']._serialized_start=8721
  _globals['_SECURITYSCORERESPONSE_CATEGORYSCORESENTRY']._serialized_end=8774
  _globals['_SUPPRESSION']._serialized_start=8777
  _globals['_SUPPRESSION']._serialized_end=8961
  _globals['_ADDSUPPRESSIONREQUEST']._serialized_start=8964
  _globals['_ADDSUPPRESSIONREQUEST']._serialized_end=9126
  _globals['_ADDSUPPRESSIONRESPONSE']._serialized_start=9128
  _globals['_ADDSUPPRESSIONRESPONSE']._serialized_end=9234
  _globals['_REMOVESUPPRESSIONREQUEST']._serialized_start=9236
  _globals['_REMOVESUPPRESSIONREQUEST']._serialized_end=9286
  _globals['_REMOVESUPPRESSIONRESPONSE']._serialized_start=9288
  _globals['_REMOVESUPPRESSIONRESPONSE']._serialized_end=9355
  _globals['_SUPPRESSIONLIST']._serialized_start=9357
  _globals['_SUPPRESSIONLIST']._serialized_end=9438
  _globals['_CHECKSUPPRESSIONREQUEST']._serialized_start=9440
  _globals['_CHECKSUPPRESSIONREQUEST']._serialized_end=9522
  _globals['_CHECKSUPPRESSIONRESPONSE']._serialized_start=9524
  _globals['_CHECKSUPPRESSIONRESPONSE']._serialized_end=9631
  _globals['_UPDATECONFIGREQUEST']._serialized_start=9634
  _globals['_UPDATECONFIGREQUEST']._serialized_end=9765
  _globals['_UPDATECONFIGREQUEST_SETTINGSENTRY']._serialized_start=9718
  _globals['_UPDATECONFIGREQUEST_SETTINGSENTRY']._serialized_end=9765
  _globals['_UPDATECONFIGRESPONSE']._serialized_start=9767
  _globals['_UPDATECONFIGRESPONSE']._serialized_end=9829
  _globals['_UPDATEFRAMESTATUSREQUEST']._serialized_start=9831
  _globals['_UPDATEFRAMESTATUSREQUEST']._serialized_end=9892
  _globals['_UPDATEFRAMESTATUSRESPONSE']._serialized_start=9894
  _globals['_UPDATEFRAMESTATUSRESPONSE']._serialized_end=9991
  _globals['_CLASSIFYREQUEST']._serialized_start=9993
  _globals['_CLASSIFYREQUEST']._serialized_end=10043
  _globals['_CLASSIFYRESULT']._serialized_start=10046
  _globals['_CLASSIFYRESULT']._serialized_end=10336
  _globals['_FRAME']._serialized_start=10338
  _globals['_FRAME']._serialized_end=10461
  _globals['_FRAMELIST']._serialized_start=10463
  _globals['_FRAMELIST']._serialized_end=10505
  _globals['_PROVIDER']._serialized_start=10507
  _globals['_PROVIDER']._serialized_end=10598
  _globals['_PROVIDERLIST']._serialized_start=10600
  _globals['_PROVIDERLIST']._serialized_end=10677
  _globals['_CONFIGURATIONRESPONSE']._serialized_start=10680
  _globals['_CONFIGURATIONRESPONSE']._serialized_end=10978
  _globals['_CONFIGURATIONRESPONSE_SETTINGSENTRY']._serialized_start=9718
  _globals['_CONFIGURATIONRESPONSE_SETTINGSENTRY']._serialized_end=9765
  _globals['_HEALTHRESPONSE']._serialized_start=10981
  _globals['_HEALTHRESPONSE']._serialized_end=11166
  _globals['_HEALTHRESPONSE_COMPONENTSENTRY']._serialized_start=11117
  _globals['_HEALTHRESPONSE_COMPONENTSENTRY']._serialized_end=11166
  _globals['_STATUSRESPONSE']._serialized_start=11169
  _globals['_STATUSRESPONSE']._serialized_end=11313
  _globals['_PIPELINEREQUEST']._serialized_start=11316
  _globals['_PIPELINEREQUEST']._serialized_end=11509
  _globals['_PIPELINEREQUEST_OPTIONSENTRY']._serialized_start=11463
  _globals['_PIPELINEREQUEST_OPTIONSENTRY']._serialized_end=11509
  _globals['_PIPELINERESULT']._serialized_start=11512
  _globals['_PIPELINERESULT']._serialized_end=11858
  _globals['_PIPELINEEVENT']._serialized_start=11861
  _globals['_PIPELINEEVENT']._serialized_end=12084
  _globals['_WARDENSERVICE']._serialized_start=12557
  _globals['_WARDENSERVICE']._serialized_end=16049
# @@protoc_insertion_point(module_scope)
