"""
Warden Runtime Services
======================

This package contains entry points for running Warden as a service.
- ipc_entry: Launches the IPC server for CLI communication
- grpc_entry: Launches the gRPC server for external clients
"""
